---
title: '[공지] 결제사 정산 서비스 지원 중단 및 신규 서비스 안내'
category: 공지사항
tags:
  - 공통
  - 공지사항
searchTags:
  - 정산 서비스
  - 거래대사 정산 서비스
  - 거래대사
  - 결제사정산
datetime: 2024-07-08T05:47:06.710Z
---

안녕하세요. PortOne팀입니다.

항상 저희 포트원을 이용해 주셔서 감사드립니다.

포트원의 "결제사 정산" 서비스에 깊은 관심과 경험을 통한 여러 피드백을 기반으로 기존의 거래 마감 데이터가 아닌 PG사의 정산 데이터를 사용하여 데이터 정합성이 높은 "PG 거래대사" 서비스를 오픈 예정입니다.

아래 안내사항 참고하셔서 서비스 이용에 불편함이 없으시도록 참고 부탁드립니다.

<Callout content="1. 결제사 정산 서비스 중단 
- 결제대행사 및 내부 정책에 따라 데이터 추출 기준 변경 
(기존 결제사정산 서비스 →  PG 거래대사 서비스로 업데이트)
- 종료일 : 2024.06.30 

**2. (구)토스페이먼츠 , 나이스페이먼츠 이용 시** 
- 결제대행사 내부정책에 따라 정산 ↔ 거래마감 데이터 동시제공 불가 
- 업데이트 기간 동안 신규데이터 업로드 안됨 
-  2024.07.08 ~ 07.22

※ 과거 데이터( ~2024.06.30까지)에 열람 및 Excel 다운로드는 2024.12.31 까지 가능합니다.) 

3. PG거래대사 서비스 클로즈베타 (무료)
- 오픈일정 : 2024.07.01 ~
- 지원 기능 무료 제공 
- Standard :   통합 PG 정산 데이터 확인  (거래 정산내역, 거래건별 조회) , 통합PG 부가가치세 확인 , *거래대사
-  PG거래대사 클로즈베타 서비스 신청 후 이용가능 " icon="💡" title="안내사항" />

- [PG거래대사 클로즈베타 서비스 신청하러 가기↗ (클릭)](https://docs.google.com/forms/d/e/1FAIpQLSeTscoLKYvddYP-V3xkFCO3LwjmDjhsgrXkJZIM98sbbkb62A/viewform)
